//
//	aegis - project change supervisor
//	Copyright (C) 2002-2005 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to manipulate ae_ps
//

#include <aecomplete/command/ae_p.h>
#include <aecomplete/command/private.h>
#include <aecomplete/complete/project/name.h>
#include <aecomplete/complete/project/name.h>


static void
destructor(command_ty *this_thing)
{
}

static complete_ty *
completion_get(command_ty *cmd)
{
    return complete_project_name();
}


static command_vtbl_ty vtbl =
{
    destructor,
    completion_get,
    sizeof(command_ty),
    "ae_p",
};


command_ty *
command_ae_p()
{
    return command_new(&vtbl);
}
